#ifndef CLASERDRIVER_IGPS_H
#define CLASERDRIVER_IGPS_H

#include "claserdriver_base.h"
class CMSerialPort;

class CLaserDriver_IGPS : public CLaserDriver_Base
{
public:
    enum msg_id
    {
        LASERDRIVER_IGPS_MSG_ID=MAX_LASERDRIVER_MSG_ID,
        MAX_LASERDRIVER_IGPS_MSG_ID,
    };
    CLaserDriver_IGPS(const QString& name,int32_t id);
    ~CLaserDriver_IGPS();
public:
    int32_t init_driver();
    int32_t exit_driver();
    WORD SendCommand(WORD wCommand ,WORD wdata ,BOOL bWrite);
public:
    virtual int SetFreq(int32_t laserid,float64_t dFreq);
    virtual int GetFreq(int32_t laserid);
    virtual int OpenLaserGate(int32_t laserid,bool_t bOpen);
    virtual int SetPowerRate(int32_t laserid, float64_t dPower);
    virtual int GetPowerRate(int32_t laserid);
    virtual int SetGateSource(int32_t laserid, bool_t bInt);

    virtual int GetSerial(int32_t laserid);
};

#endif // CLASERDRIVER_IGPS_H
